Ans="""

0xxx 	Class A 	general purpose unicast addresses with standard 8 bit prefix
10xx 	Class B 	general purpose unicast addresses with standard 16 bit prefix
110x 	Class C 	general purpose unicast addresses with standard 24 bit prefix
1110 	Class D 	IP Multicast Addresses - 28 bit prefix, non- aggregatable
1111 	Class E 	reserved for experimental use 

"""
