Ans='''"""

import matplotlib.pyplot as plt
import numpy as np
x=[2,4,6,8,10,12]
y=[2,2,2,2,2,2]
plt.plot(x,y,'b')
plt.xlabel('input')
plt.ylabel('steps')
plt.title('Constant complexity')
plt.show()

"""
'''
