Ans="""





3. Fiber-optic Cable

New transmission medium used by telephone companies in place of long-distance trunk lines.
This cable also used by private companies in implementing local data communication networks.
Optical fiber consists of a glass cladding with slightly lower refractive index.
Fiber optic cable is used as the high speed backbone.
Fiber Optic Advantages Greater capacity (bandwidth of up to 2 Gbps).
Smaller size and lighter weight.
Lower attenuation.
immunity to environmental interference.
highly secure due to tap difficulty and lack of signal radiation.
Fiber Optic Disadvantages expensive over short distance
requires highly skilled installers adding additional nodes is difficult
Applications
The fiber optic cable is often found in backbone networks because its bandwidth is cost effective.
Used in TV companies.
LAN such as 100 Base-FX Network 

"""
