Ans="""

13.4 GIGABIT ETHERNET
The need for an even higher data rate resulted in the design of the Gigabit Ethernet
Protocol (1000 Mbps). The IEEE committee calls it the Standard 802.3z. The goals of
the Gigabit Ethernet were to upgrade the data rate to 1 Gbps, but keep the address
length, the frame format, and the maximum and minimum frame length the same. The
goals of the Gigabit Ethernet design can be summarized as follows:
1. Upgrade the data rate to 1 Gbps.
2. Make it compatible with Standard or Fast Ethernet.
3. Use the same 48-bit address.
4. Use the same frame format.
5. Keep the same minimum and maximum frame lengths.
6. Support autonegotiation as defined in Fast Ethernet.

"""
