Ans="""

    using System;  
       namespace Animal  
        {
        class type{
        public void reptiles(){Console.WriteLine("snake")};
        public void birds(){Console.WriteLine("pigeon")};
        public void mammals(){Console.WriteLine("goat")};
        }
        }
    class program
    {
    static void main(String[] args)
    {
    animal type a=new animal.type();
    a.reptiles()
    a.birds()
    a.mammals()

    }

    }
        

"""
