Ans="""

1. Twisted Pair Cable

A transmission medium consisting of pairs of twisted copper wires arranged in a regular spiral pattern to minimize the electromagnetic interference between adjacent pairs. Low frequency transmission medium only can transmit 1 Mbps over short distances. They are mainly used to transmit analog signals but they can be used for digital signals.
Twisted Pair Advantages
Inexpensive and readily available
Flexible and light weight
Easy to work with and install
Twisted Pair Disadvantages
Susceptibility to interference and noise Attenuation problem
For analog, repeaters needed every 5-6km
For digital, repeaters needed every 2-3km
Relatively low bandwidth (3000Hz)
Applications
They are used in telephone lines to provide voice and data channels.
Local area networks, such as 10 Base-T and 100 Base-T also use twisted-pair cables.
"""

"""
2. Coaxial Cable

Coaxial cable consists of a core made of solid copper surrounded by insulation a braided metal shielding and an outer cover.
A transmission medium consisting of thickly insulated copper wire which can transmit a large volume of data than twisted wire.
Coax Advantages
Higher bandwidth 400 to 600Mhz
up to 10,800 voice conversations
Much less susceptible to interference than twisted pair
Coax Disadvantages
High attenuation rate makes it expensive over long distance
Bulky
Applications
It is used in cable TV networks
It is used in traditional Ethernet LANs.

3. Fiber-optic Cable

New transmission medium used by telephone companies in place of long-distance trunk lines.
This cable also used by private companies in implementing local data communication networks.
Optical fiber consists of a glass cladding with slightly lower refractive index.
Fiber optic cable is used as the high speed backbone.
Fiber Optic Advantages Greater capacity (bandwidth of up to 2 Gbps).
Smaller size and lighter weight.
Lower attenuation.
immunity to environmental interference.
highly secure due to tap difficulty and lack of signal radiation.
Fiber Optic Disadvantages expensive over short distance
requires highly skilled installers adding additional nodes is difficult
Applications
The fiber optic cable is often found in backbone networks because its bandwidth is cost effective.
Used in TV companies.
LAN such as 100 Base-FX Network 

"""
