Ans="""

13.3 FAST ETHERNET (100 MBPS)
In the 1990s, some LAN technologies with transmission rates higher than 10 Mbps,
such as FDDI and Fiber Channel, appeared on the market. If the Standard Ethernet
wanted to survive, it had to compete with these technologies. Ethernet made a big jump
by increasing the transmission rate to 100 Mbps, and the new generation was called the
Fast Ethernet. The designers of the Fast Ethernet needed to make it compatible with
the Standard Ethernet. The MAC sublayer was left unchanged, which meant the frame
format and the maximum and minimum size could also remain unchanged. By increasing
the transmission rate, features of the Standard Ethernet that depend on the transmission
rate, access method, and implementation had to be reconsidered. The goals of Fast Ether-
net can be summarized as follows:
1. Upgrade the data rate to 100 Mbps.
2. Make it compatible with Standard Ethernet.
3. Keep the same 48-bit address.
4. Keep the same frame format

"""
