Ans="""

ip.addr(spcfc ip)
ip.src(spcfc src)
ip.dst(spcfc dst)
http.request(http request)
http.response.code=200(packets with no errors)
tcp.port==80||udp.port==80(packets on port 80)
tcp contains facebook(catch packets containing facebook)
http,tcp,icmp,udp,ftp(corres protocol)


"""
