Ans="""

Star:- 4PCS in plus sign, 1 hub in between
Mesh:- 4 Switches connected to each other, each connected to 1 pc
Bus:- One Server connected to one switch with pc attached. The switch connected to 2 identical PC wala switches
Ring:- Benzene ring of switches with one pc each
Hub Connected to 5 PCs
Switch Connected to 6 PCs


"""
