Ans="""





Wireless (Unguided Media) Transmission transmission and reception are achieved by means of an antenna directional
transmitting antenna puts out focused beam
transmitter and receiver must be aligned omnidirectional
signal spreads out in all directions
can be received by many antennas
Wireless Examples terrestrial microwave satellite microwave broadcast radio infrared 

"""
