Ans="""

Aim: Study of different types of Network cables and Practically implement the cross-wired 
cable and straight through cable using clamping tool. 
Apparatus (Components): RJ-45 connector, Climping Tool, Twisted pair Cable 
Procedure: To do these practical following steps should be done: 
1. Start by stripping off about 2 inches of the plastic jacket off the end of the cable. Be very 
careful at this point, as to not nick or cut into the wires, which are inside. Doing so could alter 
the characteristics of your cable, or even worse render is useless. Check the wires, one more 
time for nicks or cuts. If there are any, just whack the whole end off, and start over. 
2. Spread the wires apart, but be sure to hold onto the base of the jacket with your other hand. 
You do not want the wires to become untwisted down inside the jacket. Category 5 cable 
must only have 1/2 of an inch of 'untwisted' wire at the end; otherwise it will be 'out of spec'. 
At this point, you obviously have ALOT more than 1/2 of an inch of un-twisted wire. 
3. You have 2 end jacks, which must be installed on your cable. If you are using a pre-made 
cable, with one of the ends whacked off, you only have one end to install - the crossed over 
end. Below are two diagrams, which show how you need to arrange the cables for each type 
of cable end.

RJ45(END 1)
Wh/Or
Or
Wh/Gr
Bl
Wh/Bl
Gr
Wh/Br
Br
RJ45(END 1)
Wh/Gr
Gr
Wh/Or
Wh/Br
Br
Or
Bl
Wh/Bl


"""
